@@ -1,7 +1,4 @@
-
-require 5;
 package HTML::AsSubs;
-#Time-stamp: "2000-05-18 23:40:33 MDT"
 
 =head1 NAME
 
@@ -25,7 +22,7 @@ HTML::AsSubs - functions that construct a HTML syntax tree
 
 This module exports functions that can be used to construct various
 HTML elements. The functions are named after the tags of the
-correponding HTML element and are all written in lower case. If the
+corresponding HTML element and are all written in lower case. If the
 first argument is a hash reference then it will be used to initialize the
 attributes of this element. The remaining arguments are regarded as
 content.
@@ -34,6 +31,11 @@ For a similar idea (i.e., it's another case where the syntax tree
 of the Perl source mirrors the syntax tree of the HTML produced),
 see HTML::Element's C<new_from_lol> method.
 
+For what I now think is a cleaner implementation of this same idea,
+see the excellent module C<XML::Generator>, which is what I suggest
+for actual real-life use.  (I suggest this over C<HTML::AsSubs> and
+over C<CGI.pm>'s HTML-making functions.)
+
 =head1 ACKNOWLEDGEMENT
 
 This module was inspired by the following message:
@@ -64,10 +66,11 @@ because it clashes with the builtin tr/../../ operator.
 
 =head1 SEE ALSO
 
-L<HTML::Element>
+L<HTML::Element>, L<XML::Generator>
 
 =cut
 
+use warnings;
 use strict;
 use vars qw(@ISA $VERSION @EXPORT);
 
@@ -75,42 +78,63 @@ require HTML::Element;
 require Exporter;
 @ISA = qw(Exporter);
 
-$VERSION = '1.15';
+$VERSION = '1.16';
+
+# Problem: exports so damned much.  Has no concept of "export only HTML4
+#  elements".  TODO:?? make something that make functions that just
+#  wrap XML::Generator calls?
+
+=head2 html head title base link meta isindex nextid script style body h1 h2 h3 h4 h5 h6 p pre div blockquote a img br hr ol ul dir menu li dl dt dd dfn cite code em kbd samp strong var address span b i u tt center font big small strike sub sup table tr td th caption form input select option textarea object applet param map area frame frameset noframe
+
+A bunch of methods for creating tags.
+
+=cut
 
 use vars qw(@TAGS);
 @TAGS = qw(html
-	   head title base link meta isindex nextid script style
-	   body h1 h2 h3 h4 h5 h6 p pre div blockquote
-	   a img br hr
-	   ol ul dir menu li
-	   dl dt dd
-	   dfn cite code em kbd samp strong var address 
-	   b i u tt
-           center font big small strike
-           sub sup
-	   table tr td th caption
-	   form input select option textarea
-           object applet param
-           map area
-           frame frameset noframe
-	  );
+    head title base link meta isindex nextid script style
+    body h1 h2 h3 h4 h5 h6 p pre div blockquote
+    a img br hr
+    ol ul dir menu li
+    dl dt dd
+    dfn cite code em kbd samp strong var address span
+    b i u tt
+    center font big small strike
+    sub sup
+    table tr td th caption
+    form input select option textarea
+    object applet param
+    map area
+    frame frameset noframe
+);
 
-my @code;
 for (@TAGS) {
-    push(@code, "sub $_ { _elem('$_', \@_); }\n");
-    push(@EXPORT, $_);
-}
-eval join('', @code);
-if ($@) {
-    die $@;
+    my $code;
+    $code = "sub $_ { _elem('$_', \@_); }\n";
+    push( @EXPORT, $_ );
+## no critic
+    eval $code;
+## use critic
+    if ($@) {
+        die $@;
+    }
 }
 
-sub _elem
-{
+=head1 Private Functions
+
+=head2 _elem()
+
+The _elem() function is wrapped by all the html 'tag' functions. It
+takes a tag-name, optional hashref of attributes and a list of content
+as parameters.
+
+=cut
+
+sub _elem {
     my $tag = shift;
     my $attributes;
-    if (@_ and defined $_[0] and ref($_[0]) eq "HASH") {
-	$attributes = shift;
+    if ( @_ and defined $_[0] and ref( $_[0] ) eq "HASH" ) {
+        $attributes = shift;
     }
     my $elem = HTML::Element->new( $tag, %$attributes );
     $elem->push_content(@_);
